Documentation
¶
Overview ¶
Package fischerchess implements Fischer Random Chess (Chess960) specific functionality on top of the standard chess library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Variants = [960]string{}/* 960 elements not displayed */
Variants contains the 960 valid starting positions for Fischer Random Chess in FEN notation (without the side to move, castling rights, en passant target square, halfmove clock, and fullmove number).
Functions ¶
func NewBoardFilled ¶
NewBoardFilled creates a new Fischer Random Chess board with pieces arranged according to one of the 960 valid starting positions, selected randomly using the provided rand.Rand source.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.